// $Id: J4RunAction.hh,v 1.1.1.2 2001/05/31 06:35:25 hoshina Exp $
// ====================================================================
//    J4RunAction.hh
//
//    A user's optional action class which defines the user's action 
//    at the begining and the end of each run. 
//
//    The user can override the following two methods;
//      virtual void BeginOfRunAction(const G4Run* aRun);
//      virtual void EndOfRunAction(const G4Run* aRun);
//
//    This class must be set to G4RunManager via 
//    G4RunManager::SetUserAction() method.
//
//                                   .JLC-CDC, 2001
// ====================================================================
#ifndef J4_RUN_ACTION_H
#define J4_RUN_ACTION_H

#include <fstream.h>
#include "G4UserRunAction.hh"
#include "J4VHit.hh"

// ====================================================================
//
//      class definition
//
// ====================================================================

class G4Run;

class J4RunAction : public G4UserRunAction {
private:
  G4String hitFileName;
  ofstream ofs;
  
public:
  J4RunAction(const G4String& fname="hit.dat");
  ~J4RunAction() { }

  // set/get functions
  void SetHitFileName(const G4String& fname) { hitFileName= fname; }
  G4String GetHitFileName() const { return hitFileName; }

  ofstream& GetOutputFileStream() { return ofs; }

  // methods
  virtual void BeginOfRunAction(const G4Run* aRun);
  virtual void EndOfRunAction(const G4Run* aRun);
};

#endif
