// $Id: J4VHit.hh,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
#ifndef __J4VHit__
#define __J4VHit__
//*************************************************************************
//* --------------------
//* J4VHit
//* --------------------
//* (Description)
//* 	Pure abstruct hit class. This class also provide his
//*	proper HitCollection(buffering) class.
//*	Mother class : G4VHit
//*     
//* (Update Record)
//*	2001/03/15  K.Hoshina	Original version.
//*************************************************************************

#include <fstream.h>

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"
#include "J4VDetectorComponent.hh"

//=========================================================================
//---------------------
// Class definition
//---------------------

class J4VHit : public G4VHit {
public:
  J4VHit();
  J4VHit(J4VDetectorComponent*  detector,
  	 G4int			cloneID,
  	 G4int			trackID  = 0,
  	 G4ParticleDefinition*	particle = 0,
  	 G4double		tof	 = 0,
  	 G4double		edep	 = 0,
  	 G4double		totalE	 = 0,
  	 const G4ThreeVector&	momentum = G4ThreeVector(0.),
  	 const G4ThreeVector&	pre	 = G4ThreeVector(0.),
  	 const G4ThreeVector&	pos	 = G4ThreeVector(0.));	      
		       
  J4VHit(const J4VHit& right);		       
  virtual ~J4VHit();
  
  const J4VHit& operator=(const J4VHit& right); 
  
  virtual void Output(G4HCofThisEvent* HCTE)
  {
  }
  
     
    
  // Set functions
  void SetDetectorComponent (J4VDetectorComponent* detector);
  void SetParticle      (G4ParticleDefinition* p ); 
  void SetCloneID	(G4int cloneID);
  void SetTrackID       (G4int trackID); 	 
  void SetTof	        (G4double tof );    	
  void SetEnergyDeposit (G4double edep); 		
  void SetTotalEnergy   (G4double totalE);	 
  void SetMomentum      (const G4ThreeVector& momentum);
  void SetPrePosition   (const G4ThreeVector& pre);
  void SetPostPosition  (const G4ThreeVector& pos);
  
  static void SetOutputFileStream(ofstream& ofs) { fOfs = &ofs; }
  
  // Get functions
  J4VDetectorComponent* GetDetectorComponent() const;
  G4ParticleDefinition* GetParticle()   const;
  G4int	        GetCloneID      () const ;
  G4int	        GetTrackID      () const ;
  G4double      GetTof	        () const ;
  G4double      GetEnergyDeposit() const ;
  G4double      GetTotalEnergy  () const ;
  G4double	GetMass		() const ;
  G4double	GetCharge	() const ; 
  G4String&	GetDetectorComponentName () const ;
  G4ThreeVector GetMomentum     () const ;
  G4ThreeVector GetPrePosition  () const ;
  G4ThreeVector GetPostPosition () const ; 
  const G4String& GetParticleName () const ;
  
  static ofstream& GetOutputFileStream() { return *fOfs; } 
     
private:
  J4VDetectorComponent* fDetectorComponent; // the Hit occured in 
  G4int			fCloneID	; // Clone No. of sensitive detector
  G4int 		fTrackID        ; // TrackID
  G4ParticleDefinition* fParticle       ; // Name of perticle
  G4double 		fTof            ; // TOF  
  G4double 		fEnergyDeposit  ; // Energy Deposit 
  G4double      	fTotalEnergy	; // Total energy
  G4ThreeVector 	fMomentum       ; // Momentum of perticle 
  G4ThreeVector 	fPrePosition    ; // Pre-position of track 
  G4ThreeVector 	fPostPosition   ; // Post-position of track
  
  static ofstream* fOfs;
  

};

#include "J4VHit.icc"
  
#endif

