// $Id: J4CDC.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDC
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDC.hh"

#include "G4Tubs.hh"
#include "G4PVReplica.hh"
#include "G4PVPlacement.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------

G4String J4CDC::fName("CDC");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4CDC::J4CDC(J4VDetectorComponent *parent,
			    G4int nclones,
  		  	    G4int nbrothers, 
  		  	    G4int me ) :
  		J4VCDCDetectorComponent( fName, parent, nclones,
  					 nbrothers, me  ) 
{   
}

//=====================================================================
//* destructor --------------------------------------------------------

J4CDC::~J4CDC()
{
	
  if (fInnerSupportTub) delete fInnerSupportTub;
  if (fOuterSupportTub) delete fOuterSupportTub;
  	
  if (fLayers){	
    G4int i;  
    for (i = 0; i < _CDCLAYERNLAYERS_ ; i++) {
     if(fLayers[i]) delete fLayers [i];
    } 
    delete [] fLayers;
  }
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4CDC::Assemble() 
{   
  if(!GetLV()){
  	
    G4double rmin = _CDCIR_;
    G4double rmax = _CDCOR_;
    G4double len  = _CDCLEN_;
    G4double dphi = _CDCDPHI_;
  	
    // MakeSolid ----------//
    OrderNewTubs (rmin, rmax, len, dphi);
    
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()->Order(_CDCMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV(_CDCVISATT_, G4Color(1, 0, 1));
  	
    // Install daughter PV //
    // Install SupportTub       //
    
    G4double otubIR  = _CDCOUTERSUPPORTTUBIR_ ;
    G4double otubOR  = _CDCOUTERSUPPORTTUBOR_ ;
    G4double itubIR  = _CDCINNERSUPPORTTUBIR_ ;
    G4double itubOR  = _CDCINNERSUPPORTTUBOR_ ;
    G4double tublen  = _CDCSUPPORTTUBLEN_ ;
    G4double tubtphi = _CDCSUPPORTTUBDPHI_ ;
    
    fOuterSupportTub = new J4CDCSupportTub(otubIR, otubOR, tublen, tubtphi, this);
    fOuterSupportTub->InstallIn(this);
    SetDaughter(fOuterSupportTub);
    
    fInnerSupportTub = new J4CDCSupportTub(itubIR, itubOR, tublen, tubtphi, this);
    fInnerSupportTub->InstallIn(this);
    SetDaughter(fInnerSupportTub);
    
    // Install Layer       //
  		  
    fLayers = new J4CDCLayer* [_CDCLAYERNLAYERS_];
    G4int i;  
    for (i = 0; i < _CDCLAYERNLAYERS_ ; i++) {
      fLayers [i] = new J4CDCLayer(this,_CDCLAYERNCLONES_ , _CDCLAYERNLAYERS_ , i );
      fLayers [i]->InstallIn(this);  
      
      SetDaughter(fLayers[i]);
    }  
      
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4CDC::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4CDC::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object...
  
  SetPVPlacement();
  
}


//* SwitchOn  --------------------------------------------------------
void J4CDC::SwitchOn()
{
}

//* SwitchOff  --------------------------------------------------------
void J4CDC::SwitchOff()
{
}

//* Draw  --------------------------------------------------------
void J4CDC::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4CDC::Print() const
{
}

	
	
