// $Id: J4CDCCell.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCCell
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDCCell.hh"

#include "G4Tubs.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4CDCCell::fName("Cell");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4CDCCell::J4CDCCell(J4VDetectorComponent *parent,
				   G4int nclones,
  		  	           G4int nbrothers, 
  		  	           G4int me ) :
  		J4VCDCDetectorComponent( fName, parent, nclones,
  					 nbrothers, me  ) 
{   
}

//=====================================================================
//* destructor --------------------------------------------------------

J4CDCCell::~J4CDCCell()
{
  if (fDriftRegions){	
    G4int i;  
    for (i = 0; i < _CDCDriftRegionNLayers_ ; i++) {
     if(fDriftRegions[i]) delete fDriftRegions [i];
    } 
    delete [] fDriftRegions;
  }
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4CDCCell::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
    G4double len  = ((G4Tubs *)GetMother()->GetLV()->GetSolid())->
    				GetZHalfLength(); 
    G4double rmin = ((G4Tubs *)GetMother()->GetLV()->GetSolid())->
    				GetInnerRadius();       
    G4double rmax = ((G4Tubs *)GetMother()->GetLV()->GetSolid())->
    				GetOuterRadius();
    G4double motherDphi = ((G4Tubs *)GetMother()->GetLV()->
    				GetSolid())->GetDeltaPhiAngle();
    				
        
    // MakeSolid ----------//
    OrderNewTubs (rmin, rmax, len, motherDphi );
    
    // MakeLogicalVolume --//  
    MakeLVWith   (OpenMaterialStore()-> Order(_CDCCELLMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV      (_CDCCellVisAtt_, G4Color(0.,0.,1.));    
        
    // Install daughter PV //
    // Install DriftRegion //
        
    G4int nDRbrothers = _CDCDriftRegionNLayers_;
    G4int nDRclones   = _CDCDriftRegionNReplica_;

    fDriftRegions = new J4CDCDriftRegion* [nDRbrothers];
  
    G4int i;  
    for (i = 0; i < nDRbrothers; i++) {
      fDriftRegions [i]
        = new J4CDCDriftRegion(this, nDRclones, nDRbrothers, i );
      fDriftRegions [i]->InstallIn(this);   
      
      SetDaughter(fDriftRegions [i]);
    }    
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4CDCCell::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4CDCCell::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object -----//
  
  G4double motherphi = ((G4Tubs *)GetMother()->GetLV()->GetSolid())->
  			GetDeltaPhiAngle();
  G4double step      = motherphi / GetNClones() ;

  SetPVReplica(kPhi, step);
  
}


//* SwitchOn  --------------------------------------------------------
void J4CDCCell::SwitchOn()
{
}

//* SwitchOff  --------------------------------------------------------
void J4CDCCell::SwitchOff()
{
}

//* Draw  --------------------------------------------------------
void J4CDCCell::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4CDCCell::Print() const
{
}

	
	
