// $Id: J4CDCDriftRegionSD.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCDriftRegionSD
//* --------------------
//* (Description)
//* 	Class for describing his/her sensitive detector.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDCDriftRegionSD.hh"
#include <math.h>
#include "G4RotationMatrix.hh"
 
//=====================================================================
//---------------------
// class definition
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4CDCDriftRegionSD::J4CDCDriftRegionSD(J4VDetectorComponent* detector)
		   :J4VSD<J4CDCDriftRegionHit>(detector)
{  
}

//=====================================================================
//* destructor --------------------------------------------------------

J4CDCDriftRegionSD::~J4CDCDriftRegionSD()
{
}

//=====================================================================
//* Initialize --------------------------------------------------------

void J4CDCDriftRegionSD::Initialize(G4HCofThisEvent* HCTE)
{
  //create hit collection(s) and
  //push H.C. to "Hit Collection of This Event"
  
  MakeHitBuf(HCTE);  
  
// G4cerr <<" J4CDCDriftRegion:Initialize is called " << G4endl;
  
}

//=====================================================================
//* ProcessHits -------------------------------------------------------


// !! ATTENTION !!
// This is test varsion. You MUST change it.


G4bool J4CDCDriftRegionSD::ProcessHits(G4Step* aStep, G4TouchableHistory* ROhist)
{
	
  //In order to use Get function, you must call SetNewStep() at first.
  
  SetNewStep(aStep);
   
  //Only when a charged particle has just come into a sensitive detector,
  //create a new hit
  
  if(GetCharge() == 0.) return FALSE;
  
      
  //Get perticle information

  J4VDetectorComponent* location = GetDetectorComponent();
  G4int trackID  		 = GetTrackID();
  G4ParticleDefinition* particle = GetParticle();
  G4double tof      		 = GetTof();
  G4double edep  		 = GetEnergyDeposit();
  G4double etot  		 = GetTotalEnergy();
  G4ThreeVector p 	 	 = GetMomentum();
  const G4ThreeVector& pre	 = GetPrePosition();
  const G4ThreeVector& pos	 = GetPostPosition();
  
  G4int	cloneID  = GetPreStepPoint()->GetTouchable()->GetReplicaNumber();  
  const G4RotationMatrix* cellRot 
  		 = GetPreStepPoint()->GetTouchable()->GetRotation();  
#if 0

  G4cerr << "cellRot.phiX() = " << cellRot->phiX() << G4endl; 
  
#endif  


#if 0 
  G4cerr << "SDname = " << location->GetName() << " " 
  	 << "TrackID = " << trackID << " " 
  	 << "ParticleName = " << particle->GetParticleName() << " "
  	 << "PreStepPoint(x,y,z) = " << pre.x() << " " 
  	 << pre.y() << " " << pre.z() << G4endl; 
#endif

#if 1

  // Create a new hit and push them to "Hit Coleltion"
 
     J4CDCDriftRegionHit* hit = 
       new J4CDCDriftRegionHit( location, cloneID, trackID, particle,
       			      tof, edep, etot, p, pre, pos);
       			      
     hit->SetCellRotation(*cellRot);
 
     ((J4CDCDriftRegionHitBuf*)GetHitBuf())-> insert(hit);
#endif

     return TRUE;
}

//=====================================================================
//* EndOfEvent --------------------------------------------------------

void J4CDCDriftRegionSD::EndOfEvent(G4HCofThisEvent* HCTE)
{			
}

//=====================================================================
//* clear -------------------------------------------------------------


//=====================================================================
//* DrawAll -----------------------------------------------------------

void J4CDCDriftRegionSD::DrawAll()
{
}

//=====================================================================
//* PrintAll ----------------------------------------------------------

void J4CDCDriftRegionSD::PrintAll()
{
  G4int nHit= ((J4CDCDriftRegionHitBuf*)GetHitBuf())-> entries();
  G4cout << "------------------------------------------" << G4endl
         << "*** tracker Hit (#hits=" << nHit << ")" << G4endl;
  ((J4CDCDriftRegionHitBuf*)GetHitBuf())-> PrintAllHits();
}

