// $Id: J4CDCLayer.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCLayer
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDCLayer.hh"

#include "G4Tubs.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4CDCLayer::fName("Layer");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4CDCLayer::J4CDCLayer(J4VDetectorComponent* parent,
				      G4int  nclones,
  		  	              G4int  nbrothers, 
  		  	              G4int  me ) :
  	   J4VCDCDetectorComponent(fName, parent, nclones,nbrothers, me),
  	   fRmin(0), fRmax(0), fLen(0), fTotalPhi(0), fOffset(0), 
  	   fNClonesOfCell(0)
{   

  // Define Layer parameters ----------------//    
    G4double motherRmin  = _CDCIR_;
    G4double shieldThick = _CDCSHIELDTHICK_;
    G4double layerThick  = _CDCLAYERTHICK_;
  
    fRmin = motherRmin + shieldThick + (layerThick + shieldThick) * me;
    fRmax = motherRmin + (layerThick + shieldThick) * (me + 1);
    fLen  = ((G4Tubs *)parent->GetLV()->GetSolid())->GetZHalfLength(); 
    fTotalPhi = ((G4Tubs *)parent->GetLV()->GetSolid())->GetDeltaPhiAngle();
    fOffset   = 0.;
    
  // Define number of cell in a layer -------//    
  
    fNClonesOfCell = (me > 2 ? (me > 5 ? 6:4 ) : 3) * 18;
    				
}

J4CDCLayer::J4CDCLayer(G4double 	   rmin,
		       G4double 	   rmax,
		       G4double 	   len,
		       G4int  		   ncellclones,
		       G4double 	   offset, 
		       J4VDetectorComponent* parent,
		       G4int  		   nclones,
  		       G4int 		   nbrothers, 
  		       G4int		   me ) :
  	   J4VCDCDetectorComponent(fName, parent, nclones, nbrothers, me),
  	   fRmin(0), fRmax(0), fLen(0), fTotalPhi(0), fOffset(0), 
  	   fNClonesOfCell(0) 
{   

    fRmin = rmin;
    fRmax = rmax;
    fLen  = len; 
    fTotalPhi = ((G4Tubs *)parent->GetLV()->GetSolid())->GetDeltaPhiAngle();
    fOffset   = offset;
    
    fNClonesOfCell = ncellclones;
    				
}

//=====================================================================
//* destructor --------------------------------------------------------

J4CDCLayer::~J4CDCLayer()
{
  if(fCell) delete fCell;
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4CDCLayer::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
      
    // MakeSolid ----------//
    OrderNewTubs (fRmin, fRmax, fLen, fTotalPhi );
    
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()-> Order(_CDCLAYERMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV( _CDCLAYERVISATT_ , G4Color(1.,0.5,1.));    
        
    // Install daughter PV //
    // Install Cell        //
  
    fCell = new J4CDCCell(this, fNClonesOfCell);
    fCell->InstallIn(this);   
    
    SetDaughter(fCell);
    
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4CDCLayer::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4CDCLayer::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object ------//
  
  SetPVPlacement();
  
}


//* SwitchOn  --------------------------------------------------------
void J4CDCLayer::SwitchOn()
{
}

//* SwitchOff  --------------------------------------------------------
void J4CDCLayer::SwitchOff()
{
}

//* Draw  --------------------------------------------------------
void J4CDCLayer::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4CDCLayer::Print() const
{
}

	
	
