// $Id: J4VTXLayer.cc,v 1.1.1.2 2001/05/31 06:35:26 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTXLayer
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTXLayer.hh"

#include "G4Tubs.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------


G4String J4VTXLayer::fName("Layer");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTXLayer::J4VTXLayer(J4VDetectorComponent* parent,
				      G4int  nclones,
  		  	              G4int  nbrothers, 
  		  	              G4int  me ) :
  	   J4VVTXDetectorComponent(fName, parent, nclones,nbrothers, me),
  	   fRmin(0), fRmax(0), fLen(0), fTotalPhi(0), fOffset(0)
{   

  // Define Layer parameters ----------------//    
    G4double startR      = _VTXLAYER1IR_;
    G4double incrementR  = _VTXLAYERINCREMENTR_;
    G4double layerThick  = _VTXLAYERTHICK_;
    G4double startLen    = _VTXLAYER1LEN_;
    G4double incrementZ  = _VTXLAYERINCREMENTZ_;

    fRmin = startR + incrementR * me;
    fRmax = (startR + incrementR * me) + layerThick; 
    fLen  = startLen + incrementZ * me;
    fTotalPhi = ((G4Tubs *)parent->GetLV()->GetSolid())->GetDeltaPhiAngle();
    fOffset   = 0.;
    
}

J4VTXLayer::J4VTXLayer(G4double 	   rmin,
		       G4double 	   rmax,
		       G4double 	   len,
		       G4double 	   offset, 
		       J4VDetectorComponent* parent,
		       G4int  		   nclones,
  		       G4int 		   nbrothers, 
  		       G4int		   me ) :
  	   J4VVTXDetectorComponent(fName, parent, nclones, nbrothers, me),
  	   fRmin(0), fRmax(0), fLen(0), fTotalPhi(0), fOffset(0) 
{   

    fRmin = rmin;
    fRmax = rmax;
    fLen  = len; 
    fTotalPhi = ((G4Tubs *)parent->GetLV()->GetSolid())->GetDeltaPhiAngle();
    fOffset   = offset;
    
    				
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTXLayer::~J4VTXLayer()
{
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTXLayer::Assemble() 
{   
  if(!GetLV())
  {	  
    // define geometry
      
    // MakeSolid ----------//
    OrderNewTubs (fRmin, fRmax, fLen, fTotalPhi );
    
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()-> Order(_VTXLAYERMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV( _VTXLAYERVISATT_ , G4Color(1.,0.5,1.));    
        
    // Install daughter PV //
  
    
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTXLayer::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTXLayer::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object ------//
  
  SetPVPlacement();
  
}


//* SwitchOn  --------------------------------------------------------
void J4VTXLayer::SwitchOn()
{
}

//* SwitchOff  --------------------------------------------------------
void J4VTXLayer::SwitchOff()
{
}

//* Draw  --------------------------------------------------------
void J4VTXLayer::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTXLayer::Print() const
{
}

	
	
